---
name: Bug Report
about: Describe an issue with RMM.
title: ''
labels: ''
assignees: ''

---

**Description**
Briefly describe the issue you are having.

**Reproduction**
List the steps to reproduce the issue. Ex:
1. run 'rmm brokencommand'

**Info**
List your OS, RMM version, and RimWorld version below.
RMM version can be obtained by running `rmm -v`
